instrumenttools.ClarinetInA
===========================

.. abjad-lineage:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA

.. autoclass:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.ClarinetInA.ClarinetInA.ClarinetInA.__repr__
   :noindex:
